Package: ggpicrust2
Type: Package
Title: Make 'PICRUSt2' Output Analysis and Visualization Easier
Version: 2.5.17
Author: Chen Yang [aut, cre],
  Liangliang Zhang [aut]
Maintainer: Chen Yang <cafferychen7850@gmail.com>
Authors@R: c(
    person("Chen", "Yang", email = "cafferychen7850@gmail.com", role = c("aut", "cre")),
    person("Liangliang", "Zhang", email = "lxz716@case.edu ", role = "aut"))
Description: Provides a convenient way to analyze and visualize 'PICRUSt2' output with pre-defined plots and functions. Allows for generating statistical plots about microbiome functional predictions and offers customization options. Features a one-click option for creating publication-level plots, saving time and effort in producing professional-grade figures. Streamlines the 'PICRUSt2' analysis and visualization process. For more details, see Yang et al. (2023) <doi:10.1093/bioinformatics/btad470>.
BugReports: https://github.com/cafferychen777/ggpicrust2/issues
URL: https://github.com/cafferychen777/ggpicrust2,
        https://cafferyang.com/ggpicrust2/
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Imports: aplot, dplyr, ggplot2, grid, ggh4x, readr, tibble, tidyr,
        ggprism, patchwork, ggplotify, magrittr, progress, stats,
        methods, grDevices, tidygraph, ggraph, utils
Depends: R (>= 3.5.0)
Suggests: Biobase, ggdendro, KEGGREST, ComplexHeatmap, BiocGenerics,
        knitr, rmarkdown, testthat (>= 3.0.0), ALDEx2, DESeq2, edgeR,
        GGally, limma, MicrobiomeStat, SummarizedExperiment, circlize,
        lefser, Maaslin2, metagenomeSeq, fgsea, clusterProfiler,
        enrichplot, DOSE, ggVennDiagram, UpSetR, igraph, ggridges,
        ggrepel, logging
Config/testthat/edition: 3
biocViews: Microbiome, Metagenomics, Software
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-06-05 16:21:06 UTC; apple
Repository: CRAN
Date/Publication: 2026-06-05 16:50:02 UTC
Built: R 4.6.0; ; 2026-06-05 20:29:56 UTC; unix
