# Generated by roxygen2: do not edit by hand

export(aggregate_taxa_contributions)
export(calculate_smart_text_size)
export(compare_daa_results)
export(compare_gsea_daa)
export(compare_metagenome_results)
export(create_gradient_colors)
export(create_legend_theme)
export(create_pathway_class_theme)
export(format_pvalue_smart)
export(get_available_themes)
export(get_color_theme)
export(get_significance_colors)
export(get_significance_stars)
export(ggpicrust2)
export(gsea_pathway_annotation)
export(import_MicrobiomeAnalyst_daa_results)
export(ko2kegg_abundance)
export(pathway_annotation)
export(pathway_daa)
export(pathway_errorbar)
export(pathway_errorbar_table)
export(pathway_gsea)
export(pathway_heatmap)
export(pathway_pca)
export(pathway_ridgeplot)
export(pathway_volcano)
export(prepare_gene_sets)
export(preview_color_theme)
export(read_contrib_file)
export(read_pathway_contrib_file)
export(read_strat_file)
export(resolve_annotation_overlaps)
export(safe_extract)
export(smart_color_selection)
export(taxa_contribution_bar)
export(taxa_contribution_heatmap)
export(visualize_gsea)
import(dplyr)
import(ggplot2)
import(tidyr)
importFrom(aplot,insert_right)
importFrom(aplot,insert_top)
importFrom(dplyr,arrange)
importFrom(dplyr,case_when)
importFrom(dplyr,filter)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(dplyr,slice_head)
importFrom(dplyr,slice_max)
importFrom(ggh4x,elem_list_rect)
importFrom(ggh4x,facet_nested)
importFrom(ggh4x,strip_nested)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_line)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_density)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,stat_ellipse)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,theme_minimal)
importFrom(ggplotify,as.ggplot)
importFrom(grDevices,col2rgb)
importFrom(grDevices,colorRampPalette)
importFrom(magrittr,"%>%")
importFrom(methods,new)
importFrom(stats,as.dist)
importFrom(stats,as.formula)
importFrom(stats,cor)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,p.adjust)
importFrom(stats,prcomp)
importFrom(stats,relevel)
importFrom(stats,reorder)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(stats,wilcox.test)
importFrom(tidyr,pivot_longer)
importFrom(utils,data)
importFrom(utils,head)
