% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/legend_annotation_utils.R
\name{format_pvalue_smart}
\alias{format_pvalue_smart}
\title{Smart P-value Formatting}
\usage{
format_pvalue_smart(
  p_values,
  format = "smart",
  stars = TRUE,
  thresholds = c(0.001, 0.01, 0.05),
  star_symbols = c("***", "**", "*")
)
}
\arguments{
\item{p_values}{Numeric vector of p-values}

\item{format}{Character string specifying format type}

\item{stars}{Logical, whether to include star symbols}

\item{thresholds}{Numeric vector of significance thresholds}

\item{star_symbols}{Character vector of star symbols}
}
\value{
Character vector of formatted p-values
}
\description{
Smart P-value Formatting
}
