% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visualize_gsea.R
\name{create_empty_plot}
\alias{create_empty_plot}
\title{Create empty plot for edge cases}
\usage{
create_empty_plot(plot_type)
}
\arguments{
\item{plot_type}{A character string specifying the visualization type}
}
\value{
A ggplot2 object
}
\description{
Create empty plot for edge cases
}
\keyword{internal}
